#
# spec file for package fatrace
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2013 Philipp Thomas <pth@suse.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with tests
Name:           fatrace
Version:        0.17.0
Release:        1.6
Summary:        System wide file access event reporting utility
License:        GPL-3.0-or-later
Group:          System/Monitoring
URL:            https://github.com/martinpitt/fatrace
Source:         https://github.com/martinpitt/fatrace/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  glibc-devel

%description
The fatrace trace uses fanotify, a couple of /proc lookups and some
glue to trace file access events system-wide, in an effort to
identify processes which keep waking up the disk even when the
computer is idle.

By default, it monitors the whole system, i.e. all mounts except
virtual ones like /proc, tmpfs, etc. It can be told to monitor just
the mount of the current directory. The log can be written to a file
and runtime be capped. Optional time stamps and PID filters are also
provided.

%prep
%setup -q

%build
%make_build CFLAGS="%{optflags}" PREFIX="%{_prefix}"

%install
%make_install CFLAGS="%{optflags}" PREFIX="%{_prefix}"

%if %{with tests}
%check
sh ./tests/run
%endif

%files
%license COPYING
%doc NEWS
%{_sbindir}/%{name}
%{_sbindir}/power-usage-report
%{_mandir}/man8/%{name}.8%{?ext_man}

%changelog
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 0.17.0:
  * Work around kernel bug with blocking FAN_REPORT_FID with btrfs
  * Improve event formatting
  * Avoid ELOOP errors when monitoring symlinks
  * Monitor ZFS volumes; thanks achims311
* Mon Dec 20 2021 Dirk Müller <dmueller@suse.com>
- update to 0.16.3:
  * Always use line buffering
  * Fix fd leak with `-f` event type filtering.
* Wed May 12 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.16.2
  * Avoid most "unknown" process names on process exit
  * tests: Accept split file rename events
  * Move manpage to section 8
  * Use line buffering with --output to get live logs
  * Make open_by_handle_at() failures non-fatal
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.15:
  - Fix fd leak with -C when building without FAN_REPORT_FID support
  - Add support for directory events: file creation, rename/move, delete. This
    requires Linux 5.1 (FAN_REPORT_FID support), on older kernels fall back to
    the old mode. (Debian #940629, LP: #1371394)
  - power-usage-report: Fix regexp substitution (LP: #1683164)
  - Drop O_LARGEFILE workaround, fixes cross-building
  (Debian #784983, LP: #1755787)
* Mon Apr 15 2019 Jan Engelhardt <jengelh@inai.de>
- Trim storytelling from description.
* Mon Apr  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Run spec-cleaner
- Update to 0.13:
  * Add --filter/-f option to only show selected event types.
  * Add -C/--command option to only show events for a particular
    command.
  * Fix #include file for major() and minor() to avoid a warning
    with recent glibc.
* Mon Jan 12 2015 p.drouand@gmail.com
- Update to version 0.9
  + power-usage-report: Adjust parsing to also work for powertop 2.6.
- Clean-up spec file
- Fix project Url
- Use download Url as source
- Remove make and gcc explicit requirements; it's implicit
* Mon Apr 15 2013 cfarrell@suse.com
- license update: GPL-3.0+
  no indication of GPL-3.0 "only" license in package
* Fri Apr 12 2013 pth@suse.de
- Initial package
- Add explicit BuildRequires for glibc-devel, gcc and make
